// generated from rosidl_adapter/resource/msg.idl.em
// with input from unique_identifier_msgs/msg/UUID.msg
// generated code does not contain a copyright notice


module unique_identifier_msgs {
  module msg {
    typedef uint8 uint8__16[16];
    @verbatim (language="comment", text=
      "A universally unique identifier (UUID)." "\n"
      "" "\n"
      " http://en.wikipedia.org/wiki/Universally_unique_identifier" "\n"
      " http://tools.ietf.org/html/rfc4122.html")
    struct UUID {
      uint8__16 uuid;
    };
  };
};
